@@ -168,6 +168,8 @@ Ext.define('Pcore.direct.WebSocketProvider', {
     extend: 'Ext.direct.RemotingProvider',
     alias: 'direct.websocketprovider',
 
+    token: null,
+
     webSocket: null,
     pendingCallbacks: [],
     pendingTransactions: {},
@@ -182,10 +184,8 @@ Ext.define('Pcore.direct.WebSocketProvider', {
 
             var url = protocol + '://' + location.host + this.url;
 
-            var token = Ext.state.Manager.get('token');
-
-            if (token) {
-                url += '?access_token=' + token;
+            if (this.token) {
+                url += '?access_token=' + this.token;
             }
 
             this.webSocket = new WebSocket(url, 'pcore');
@@ -209,14 +209,22 @@ Ext.define('Pcore.direct.WebSocketProvider', {
         }
     },
 
+    setToken: function(token) {
+        if (token != this.token) {
+            this.token = token;
+
+            this.disconnect();
+        }
+    },
+
     disconnect: function () {
         if (this.webSocket) {
             this.webSocket.close(1000, 'disconnected');
 
             this.webSocket = null;
-        }
 
-        this._fireException();
+            this._fireException();
+        }
     },
 
     _onWebSocketOpen: function (e) {
